@@ -1,9 +1,5 @@
 from enum import Enum
-from typing import Dict
-from typing import List
-from typing import Sequence
-from typing import Tuple
-from typing import Union
+from typing import Dict, List, Sequence, Tuple, Union
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -129,8 +125,9 @@ def standard_lineplot(
     cat.ax.tick_params(labelsize=tick_size)
 
     if save:
-        cat.fig.savefig(f"{save}", bbox_inches="tight")
-        print(f"[bold blue]Saving figure to {save}")
+        full_save_name = f"{gene}_{save}"
+        cat.fig.savefig(f"{full_save_name}", bbox_inches="tight")
+        print(f"[bold blue]Saving figure to {full_save_name}")
 
     plt.show()
     plt.close()
@@ -767,7 +764,7 @@ def cluster_composition_stacked_barplot(
         save: Path to save the plot to
 
     Example:
-
+        .. image:: /_images/cluster_composition_stacked_barplot.png
     """
     import matplotlib.patches as mpatches
 
@@ -1091,12 +1088,12 @@ def genotype_vs_genotype_umaps(
     Example:
         .. image:: /_images/genotype_vs_genotype_umaps.png
     """
-    genotype_label_1 = adata[adata.obs[genotype_key].isin([genotype_label_1])].copy()
-    genotype_label_2 = adata[adata.obs[genotype_key].isin([genotype_label_2])].copy()
+    genotype_data_1 = adata[adata.obs[genotype_key].isin([genotype_label_1])].copy()
+    genotype_data_2 = adata[adata.obs[genotype_key].isin([genotype_label_2])].copy()
 
     fig, (ax1, ax2) = plt.subplots(1, 2, figsize=figsize)
     sc.pl.umap(
-        genotype_label_1,
+        genotype_data_1,
         color=color,
         ax=ax1,
         palette=sc.pl.palettes.default_20,
@@ -1108,7 +1105,7 @@ def genotype_vs_genotype_umaps(
         ax1.get_legend().remove()
     ax1.set_title(genotype_label_1)
     sc.pl.umap(
-        genotype_label_2,
+        genotype_data_2,
         color=color,
         ax=ax2,
         palette=sc.pl.palettes.default_20,
